zstd_compress_bound: Zstd compress bound

View source: R/RcppExports.R

zstd_compress_boundR Documentation

Zstd compress bound

Description

Exports the compress bound function from the zstd library. Returns the maximum potential compressed size of an object of length size.

Usage

zstd_compress_bound(size)

Arguments

size

A single non-negative whole number. Values larger than 2^31 - 1 are allowed as long as they can still be represented exactly by an R numeric value.

Value

A numeric scalar giving the maximum compressed size.

Examples

zstd_compress_bound(100000)
zstd_compress_bound(2^31)

qs2 documentation built on April 22, 2026, 9:07 a.m.