| qopt | R Documentation |
Get or set a global qs2 option.
qopt(parameter, value = NULL)
parameter |
A character string specifying the option to access. Must be one of "compress_level", "shuffle", "nthreads", "validate_checksum", "warn_unsupported_types", or "use_alt_rep". |
value |
If |
This function provides an interface to retrieve or update internal qs2 options such as compression level, shuffle flag, number of threads, checksum validation, warning for unsupported types, and requested ALTREP usage. It directly calls the underlying C-level functions.
The default settings are:
compress_level: 3L
shuffle: TRUE
nthreads: 1L
validate_checksum: FALSE
warn_unsupported_types: TRUE (used only in qd_save)
use_alt_rep: FALSE (accepted by qd_read and qd_deserialize, but temporarily disabled)
When parameter = "use_alt_rep" is set to TRUE, qdata reads currently
warn and fall back to ordinary character vectors.
When value is NULL, the current value of the specified option is returned.
Otherwise, the option is set to value and the new value is returned invisibly.
If value is NULL, returns the current value of the specified option.
Otherwise, sets the option and returns the new value invisibly.
# Get the current compression level:
qopt("compress_level")
# Set the compression level to 5:
qopt("compress_level", value = 5)
# Get the current shuffle setting:
qopt("shuffle")
# Get the current setting for warn_unsupported_types (used in qd_save):
qopt("warn_unsupported_types")
# Get the current setting for use_alt_rep:
qopt("use_alt_rep")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.