| rds_to_qs | R Documentation |
Converts a file saved in the RDS format to the qs2 format.
rds_to_qs(input_file, output_file, compress_level = 3)
input_file |
The |
output_file |
The |
compress_level |
The zstd compression level to use when writing the |
rds_to_qs() currently supports only gzip-compressed RDS input files.
Files that are uncompressed or use another compression format are rejected.
The shuffle parameter is currently not supported when converting from RDS to qs2.
No value is returned. The converted file is written to disk.
qs_tmp <- tempfile(fileext = ".qs2")
rds_tmp <- tempfile(fileext = ".RDS")
x <- runif(1e6)
saveRDS(x, rds_tmp, compress = "gzip")
rds_to_qs(input_file = rds_tmp, output_file = qs_tmp)
x2 <- qs_read(qs_tmp, validate_checksum = TRUE)
stopifnot(identical(x, x2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.