Learn R Programming

qs2 (version 0.2.1)

rds_to_qs: RDS to qs2 format

Description

Converts a file saved in the RDS format to the qs2 format.

Usage

rds_to_qs(input_file, output_file, compress_level = 3)

Value

No value is returned. The converted file is written to disk.

Arguments

input_file

The RDS file to convert.

output_file

The qs2 file to write.

compress_level

The zstd compression level to use when writing the qs2 file. See the qs_save help file for more details on this parameter.

Details

rds_to_qs() currently supports only gzip-compressed RDS input files. Files that are uncompressed or use another compression format are rejected.

The shuffle parameter is currently not supported when converting from RDS to qs2.

Examples

Run this code
qs_tmp <- tempfile(fileext = ".qs2")
rds_tmp <- tempfile(fileext = ".RDS")

x <- runif(1e6)
saveRDS(x, rds_tmp, compress = "gzip")
rds_to_qs(input_file = rds_tmp, output_file = qs_tmp)
x2 <- qs_read(qs_tmp, validate_checksum = TRUE)
stopifnot(identical(x, x2))

Run the code above in your browser using DataLab