| zstd_compress_bound | R Documentation |
Exports the compress bound function from the zstd library. Returns the
maximum potential compressed size of an object of length size.
zstd_compress_bound(size)
size |
A single non-negative whole number. Values larger than
|
A numeric scalar giving the maximum compressed size.
zstd_compress_bound(100000)
zstd_compress_bound(2^31)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.