Learn R Programming

qs2 (version 0.2.1)

zstd_compress_bound: Zstd compress bound

Description

Exports the compress bound function from the zstd library. Returns the maximum potential compressed size of an object of length size.

Usage

zstd_compress_bound(size)

Value

A numeric scalar giving the maximum compressed size.

Arguments

size

A single non-negative whole number. Values larger than 2^31 - 1 are allowed as long as they can still be represented exactly by an R numeric value.

Examples

Run this code
zstd_compress_bound(100000)
zstd_compress_bound(2^31)

Run the code above in your browser using DataLab